@@ -3,24 +3,24 @@ import psycopg2
 
 def create_connection(database: str, user: str, password: str, host: str, port: str, sgbd = 'postgresql'):
     """
-    @create_connection(database=env['db'], 
-    @              user=env['user'],
-    @              password=env['pass'], 
-    @              host=env['host'],
-    @              port=env['port'])
-    @
-    @Declare a db connection
-    @
-    @Args:
-    @    database (str): database name
-    @    user (str): user
-    @    password (str): password
-    @    host (str): host
-    @    port (str): port
-    @    sgbd (str, optional): Defaults to 'postgresql'. Change the sgbd string in the db connection-string
-    @
-    @Returns:
-    @    sql alchemy db engine: 
+    create_connection(database=env['db'], 
+                  user=env['user'],
+                  password=env['pass'], 
+                  host=env['host'],
+                  port=env['port'])
+    
+    Declare a db connection
+    
+    Args:
+        database (str): database name
+        user (str): user
+        password (str): password
+        host (str): host
+        port (str): port
+        sgbd (str, optional): Defaults to 'postgresql'. Change the sgbd string in the db connection-string
+    
+    Returns:
+        sql alchemy db engine: 
     """ 
     con_string = create_string_connection(database, user, password, host, port, sgbd = 'postgresql')
     ## Creating db string connection
