@@ -22,10 +22,10 @@ hello = """
 ################################################################################
 """
 
-def get_line(number_of_dots, replicable_value = "-",first_line=False):
-    line = f'\n+{replicable_value*number_of_dots}\n'
-    if first_line:
-        return line[1:]
+def get_line(number_of_dots, replicable_value = "-",skip_line_before=False, skip_line_after=False):
+    first = '\n' if skip_line_before else None
+    last  = '\n' if skip_line_after else None
+    line = f'{first}{replicable_value*number_of_dots}{last}'
     return line
 
 line = get_line(51)
\ No newline at end of file
